@@ -35,9 +35,6 @@
 #include "fr-command.h"
 #include "fr-command-cfile.h"
 
-static void fr_command_cfile_class_init  (FrCommandCFileClass *class);
-static void fr_command_cfile_init        (FrCommand           *afile);
-static void fr_command_cfile_finalize    (GObject             *object);
 
 /* Parent Class */
 
@@ -45,65 +42,59 @@ static FrCommandClass *parent_class = NULL;
 
 
 static char *
-get_uncompressed_name_from_archive (FrCommand  *comm, 
-				    const char *e_filename)
+get_uncompressed_name_from_archive (FrCommand  *comm,
+				    const char *archive)
 {
-	FrCommandCFile *comm_cfile = FR_COMMAND_CFILE (comm);
-	int             fd;
-	char            buffer[11];
-	char           *filename = NULL;
-	GString        *str = NULL;
+	GFile        *file;
+	GInputStream *stream;
+	char         *filename = NULL;
 
-	if (comm_cfile->compress_prog != FR_COMPRESS_PROGRAM_GZIP)
+	if (! is_mime_type (comm->mime_type, "application/x-gzip"))
 		return NULL;
-	
-	fd = open (e_filename, O_RDONLY);
-	if (fd < 0) 
-		return NULL;
-	
-	if (read (fd, &buffer, 11) < 11) {
-		close (fd);
-		return NULL;
-	}
 
-	/* Check whether the FLG.FNAME is set */
-	if (((unsigned char)(buffer[3]) & 0x08) != 0x08) {
-		close (fd);
-		return NULL;
-	}
+	file = g_file_new_for_path (archive);
 
-	/* Check whether the FLG.FEXTRA is set */
-	if (((unsigned char)(buffer[3]) & 0x04) == 0x04) {
-		close (fd);
-		return NULL;
-	}
-	
-	str = g_string_new ("");
-	/* Don't lose the first character */
-	g_string_append_c (str, buffer[10]);
-	while (read (fd, &buffer, 1) > 0) {
-		if (buffer[0] == '\0') {
-			close (fd);
-			filename = g_strdup (file_name_from_path (str->str));
-			g_string_free (str, TRUE);
-#ifdef DEBUG
-			g_message ("filename is: %s", filename);
-#endif
-			return filename;
+	stream = (GInputStream *) g_file_read (file, NULL, NULL);
+	if (stream != NULL) {
+		gboolean filename_present = TRUE;
+		char     buffer[10];
+
+		if (g_input_stream_read (stream, buffer, 10, NULL, NULL) >= 0) {
+			/* Check whether the FLG.FNAME is set */
+			if (((unsigned char)(buffer[3]) & 0x08) != 0x08)
+				filename_present = FALSE;
+
+			/* Check whether the FLG.FEXTRA is set */
+			if (((unsigned char)(buffer[3]) & 0x04) == 0x04)
+				filename_present = FALSE;
 		}
-		
-		g_string_append_c (str, buffer[0]);
-	}
-	
-	close (fd);
-	g_string_free (str, TRUE);
 
-	return NULL;
+		if (filename_present) {
+			GString *str = NULL;
+
+			str = g_string_new ("");
+			while (g_input_stream_read (stream, buffer, 1, NULL, NULL) > 0) {
+				if (buffer[0] == '\0') {
+					filename = g_strdup (file_name_from_path (str->str));
+#ifdef DEBUG
+					g_message ("filename is: %s", filename);
+#endif
+					break;
+				}
+				g_string_append_c (str, buffer[0]);
+			}
+			g_string_free (str, TRUE);
+		}
+		g_object_unref (stream);
+	}
+	g_object_unref (file);
+
+	return filename;
 }
 
 
 static void
-list__process_line (char     *line, 
+list__process_line (char     *line,
 		    gpointer  data)
 {
 	FrCommand  *comm = FR_COMMAND (data);
@@ -122,51 +113,50 @@ list__process_line (char     *line,
 		fdata->size = get_file_size (comm->filename);
 
 	filename = get_uncompressed_name_from_archive (comm, comm->filename);
-	if (filename == NULL) 
+	if (filename == NULL)
 		filename = remove_extension_from_path (comm->filename);
 
-	fdata->full_path = g_strconcat ("/", 
+	fdata->full_path = g_strconcat ("/",
 					file_name_from_path (filename),
 					NULL);
 	g_free (filename);
 
 	fdata->original_path = fdata->full_path + 1;
 	fdata->link = NULL;
-	fdata->modified = get_file_mtime (comm->filename);
-	
+	fdata->modified = get_file_mtime_for_path (comm->filename);
+
 	fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 	fdata->path = remove_level_from_path (fdata->full_path);
-	
+
 	if (*fdata->name == 0)
 		file_data_free (fdata);
-	else 
+	else
 		fr_command_add_file (comm, fdata);
 }
 
 
 static void
-fr_command_cfile_list (FrCommand  *comm,
-		       const char *password)
+fr_command_cfile_list (FrCommand  *comm)
 {
 	FrCommandCFile *comm_cfile = FR_COMMAND_CFILE (comm);
 
-	if (comm_cfile->compress_prog == FR_COMPRESS_PROGRAM_GZIP) {
+	if (is_mime_type (comm->mime_type, "application/x-gzip")) {
 		/* gzip let us known the uncompressed size */
 
-		fr_process_set_out_line_func (FR_COMMAND (comm)->process, 
+		fr_process_set_out_line_func (FR_COMMAND (comm)->process,
 					      list__process_line,
 					      comm);
 
 		fr_process_begin_command (comm->process, "gzip");
 		fr_process_add_arg (comm->process, "-l");
 		fr_process_add_arg (comm->process, "-q");
-		fr_process_add_arg (comm->process, comm->e_filename);
+		fr_process_add_arg (comm->process, comm->filename);
 		fr_process_end_command (comm->process);
 		fr_process_start (comm->process);
-	} 
+	}
 	else {
-		/* ... other compressors do not support this feature so 
-		 * simply use the archive size, suboptimal but there is no 
+		/* ... other compressors do not support this feature so
+		 * simply use the archive size, suboptimal but there is no
 		 * alternative. */
 
 		FileData *fdata;
@@ -175,29 +165,29 @@ fr_command_cfile_list (FrCommand  *comm,
 		fdata = file_data_new ();
 
 		filename = remove_extension_from_path (comm->filename);
-		fdata->full_path = g_strconcat ("/", 
+		fdata->full_path = g_strconcat ("/",
 						file_name_from_path (filename),
 						NULL);
 		g_free (filename);
 
 		fdata->original_path = fdata->full_path + 1;
 		fdata->link = NULL;
-		fdata->size = get_file_size (comm->filename);
-		fdata->modified = get_file_mtime (comm->filename);
-		
+		fdata->size = get_file_size_for_path (comm->filename);
+		fdata->modified = get_file_mtime_for_path (comm->filename);
+
 		fdata->name = g_strdup (file_name_from_path (fdata->full_path));
 		fdata->path = remove_level_from_path (fdata->full_path);
-		
+
 		if (*fdata->name == 0)
 			file_data_free (fdata);
-		else 
+		else
 			fr_command_add_file (comm, fdata);
-		
+
 		comm_cfile->error.type = FR_PROC_ERROR_NONE;
 		comm_cfile->error.status = 0;
-		g_signal_emit_by_name (G_OBJECT (comm), 
+		g_signal_emit_by_name (G_OBJECT (comm),
 				       "done",
-				       comm->action, 
+				       comm->action,
 				       &comm_cfile->error);
 	}
 }
@@ -205,31 +195,25 @@ fr_command_cfile_list (FrCommand  *comm,
 
 static void
 fr_command_cfile_add (FrCommand     *comm,
+		      const char    *from_file,
 		      GList         *file_list,
 		      const char    *base_dir,
 		      gboolean       update,
-		      const char    *password,
-		      FRCompression  compression)
+		      gboolean       recursive)
 {
-	FrCommandCFile *comm_cfile = FR_COMMAND_CFILE (comm);
-	const char     *filename;
-	char           *temp_dir;
-	char           *e_temp_dir;
-	char           *temp_file;
+	const char *filename;
+	char       *temp_dir;
+	char       *temp_file;
+	char       *compressed_filename;
 
 	if ((file_list == NULL) || (file_list->data == NULL))
 		return;
 
-	/* create a temp dir. */
-
-	temp_dir = get_temp_work_dir ();
-	e_temp_dir = fr_command_escape (comm, temp_dir);
-
 	/* copy file to the temp dir */
 
+	temp_dir = get_temp_work_dir (NULL);
 	filename = file_list->data;
-
-	temp_file = g_strconcat (e_temp_dir, "/", filename, NULL);
+	temp_file = g_strconcat (temp_dir, "/", filename, NULL);
 
 	fr_process_begin_command (comm->process, "cp");
 	fr_process_set_working_dir (comm->process, base_dir);
@@ -241,52 +225,39 @@ fr_command_cfile_add (FrCommand     *comm,
 
 	/**/
 
-	switch (comm_cfile->compress_prog) {
-	case FR_COMPRESS_PROGRAM_NONE:
-		break;
-		
-	case FR_COMPRESS_PROGRAM_GZIP:
+	if (is_mime_type (comm->mime_type, "application/x-gzip")) {
 		fr_process_begin_command (comm->process, "gzip");
 		fr_process_set_working_dir (comm->process, temp_dir);
 		fr_process_add_arg (comm->process, "--");
 		fr_process_add_arg (comm->process, filename);
 		fr_process_end_command (comm->process);
-		break;
-
-	case FR_COMPRESS_PROGRAM_BZIP:
-		fr_process_begin_command (comm->process, "bzip");
-		fr_process_set_working_dir (comm->process, temp_dir);
-		fr_process_add_arg (comm->process, "--");
-		fr_process_add_arg (comm->process, filename);
-		fr_process_end_command (comm->process);
-		break;
-
-	case FR_COMPRESS_PROGRAM_BZIP2:
+		compressed_filename = g_strconcat (filename, ".gz", NULL);
+	}
+	else if (is_mime_type (comm->mime_type, "application/x-bzip")) {
 		fr_process_begin_command (comm->process, "bzip2");
 		fr_process_set_working_dir (comm->process, temp_dir);
 		fr_process_add_arg (comm->process, "--");
 		fr_process_add_arg (comm->process, filename);
 		fr_process_end_command (comm->process);
-		break;
-
-	case FR_COMPRESS_PROGRAM_COMPRESS: 
+		compressed_filename = g_strconcat (filename, ".bz2", NULL);
+	}
+	else if (is_mime_type (comm->mime_type, "application/x-compress")) {
 		fr_process_begin_command (comm->process, "compress");
 		fr_process_set_working_dir (comm->process, temp_dir);
 		fr_process_add_arg (comm->process, "-f");
-		fr_process_add_arg (comm->process, "--");
 		fr_process_add_arg (comm->process, filename);
 		fr_process_end_command (comm->process);
-		break;
-
-	case FR_COMPRESS_PROGRAM_LZMA:
+		compressed_filename = g_strconcat (filename, ".Z", NULL);
+	}
+	else if (is_mime_type (comm->mime_type, "application/x-lzma")) {
 		fr_process_begin_command (comm->process, "lzma");
 		fr_process_set_working_dir (comm->process, temp_dir);
 		fr_process_add_arg (comm->process, "--");
 		fr_process_add_arg (comm->process, filename);
 		fr_process_end_command (comm->process);
-		break;
-
-	case FR_COMPRESS_PROGRAM_LZOP: /* FIXME: untested. */
+		compressed_filename = g_strconcat (filename, ".lzma", NULL);
+	}
+	else if (is_mime_type (comm->mime_type, "application/x-lzop")) {
 		fr_process_begin_command (comm->process, "lzop");
 		fr_process_set_working_dir (comm->process, temp_dir);
 		fr_process_add_arg (comm->process, "-fU");
@@ -294,18 +265,24 @@ fr_command_cfile_add (FrCommand     *comm,
 		fr_process_add_arg (comm->process, "--");
 		fr_process_add_arg (comm->process, filename);
 		fr_process_end_command (comm->process);
-		break;
+		compressed_filename = g_strconcat (filename, ".lzo", NULL);
+	}
+	else if (is_mime_type (comm->mime_type, "application/x-rzip")) {
+		fr_process_begin_command (comm->process, "rzip");
+		fr_process_set_working_dir (comm->process, temp_dir);
+		fr_process_add_arg (comm->process, filename);
+		fr_process_end_command (comm->process);
+		compressed_filename = g_strconcat (filename, ".rz", NULL);
 	}
-
 
       	/* copy compressed file to the dest dir */
 
 	fr_process_begin_command (comm->process, "cp");
-	fr_process_set_working_dir (comm->process, e_temp_dir);
+	fr_process_set_working_dir (comm->process, temp_dir);
 	fr_process_add_arg (comm->process, "-f");
 	fr_process_add_arg (comm->process, "--");
-	fr_process_add_arg (comm->process, "*");
-	fr_process_add_arg (comm->process, comm->e_filename);
+	fr_process_add_arg (comm->process, compressed_filename);
+	fr_process_add_arg (comm->process, comm->filename);
 	fr_process_end_command (comm->process);
 
 	/* remove the temp dir */
@@ -314,18 +291,19 @@ fr_command_cfile_add (FrCommand     *comm,
 	fr_process_set_sticky (comm->process, TRUE);
 	fr_process_add_arg (comm->process, "-rf");
 	fr_process_add_arg (comm->process, "--");
-	fr_process_add_arg (comm->process, e_temp_dir);
+	fr_process_add_arg (comm->process, temp_dir);
 	fr_process_end_command (comm->process);
 
+	g_free (compressed_filename);
 	g_free (temp_file);
-	g_free (e_temp_dir);
 	g_free (temp_dir);
 }
 
 
 static void
-fr_command_cfile_delete (FrCommand *comm,
-			 GList     *file_list)
+fr_command_cfile_delete (FrCommand  *comm,
+			 const char *from_file,
+			 GList      *file_list)
 {
 	/* never called */
 }
@@ -333,120 +311,102 @@ fr_command_cfile_delete (FrCommand *comm,
 
 static void
 fr_command_cfile_extract (FrCommand  *comm,
+			  const char *from_file,
 			  GList      *file_list,
 			  const char *dest_dir,
 			  gboolean    overwrite,
 			  gboolean    skip_older,
-			  gboolean    junk_paths,
-			  const char *password)
+			  gboolean    junk_paths)
 {
-	FrCommandCFile *comm_cfile = FR_COMMAND_CFILE (comm);
-	char           *temp_dir;
-	char           *e_temp_dir;
-	char           *dest_file;
-	char           *e_dest_file;
-	char           *temp_file;
-	char           *e_temp_file;
-	char           *uncompr_file;
-	char           *e_uncompr_file;
-	char           *compr_file;
-
-	/* create a temp dir. */
-
-	temp_dir = get_temp_work_dir ();
-	e_temp_dir = fr_command_escape (comm, temp_dir);
+	char *temp_dir;
+	char *dest_file;
+	char *temp_file;
+	char *uncompr_file;
+	char *compr_file;
 
 	/* copy file to the temp dir, remove the already existing file first */
 
+	temp_dir = get_temp_work_dir (NULL);
 	temp_file = g_strconcat (temp_dir,
 				 "/",
 				 file_name_from_path (comm->filename),
 				 NULL);
-	e_temp_file = fr_command_escape (comm, temp_file);
 
 	fr_process_begin_command (comm->process, "cp");
 	fr_process_add_arg (comm->process, "-f");
-	fr_process_add_arg (comm->process, comm->e_filename);
-	fr_process_add_arg (comm->process, e_temp_file);
+	fr_process_add_arg (comm->process, comm->filename);
+	fr_process_add_arg (comm->process, temp_file);
 	fr_process_end_command (comm->process);
 
 	/* uncompress the file */
 
-	switch (comm_cfile->compress_prog) {
-	case FR_COMPRESS_PROGRAM_NONE:
-		break;
-		
-	case FR_COMPRESS_PROGRAM_GZIP:
+	if (is_mime_type (comm->mime_type, "application/x-gzip")) {
 		fr_process_begin_command (comm->process, "gzip");
 		fr_process_add_arg (comm->process, "-f");
 		fr_process_add_arg (comm->process, "-d");
 		fr_process_add_arg (comm->process, "-n");
-		fr_process_add_arg (comm->process, e_temp_file);
+		fr_process_add_arg (comm->process, temp_file);
 		fr_process_end_command (comm->process);
-		break;
-
-	case FR_COMPRESS_PROGRAM_BZIP:
-		fr_process_begin_command (comm->process, "bzip");
-		fr_process_add_arg (comm->process, "-f");
-		fr_process_add_arg (comm->process, "-d");
-		fr_process_add_arg (comm->process, e_temp_file);
-		fr_process_end_command (comm->process);
-		break;
-
-	case FR_COMPRESS_PROGRAM_BZIP2:
+	}
+	else if (is_mime_type (comm->mime_type, "application/x-bzip")) {
 		fr_process_begin_command (comm->process, "bzip2");
 		fr_process_add_arg (comm->process, "-f");
 		fr_process_add_arg (comm->process, "-d");
-		fr_process_add_arg (comm->process, e_temp_file);
+		fr_process_add_arg (comm->process, temp_file);
 		fr_process_end_command (comm->process);
-		break;
-
-	case FR_COMPRESS_PROGRAM_COMPRESS: 
-		fr_process_begin_command (comm->process, "uncompress");
+	}
+	else if (is_mime_type (comm->mime_type, "application/x-compress")) {
+		if (is_program_in_path ("gzip")) {
+			fr_process_begin_command (comm->process, "gzip");
+			fr_process_add_arg (comm->process, "-d");
+			fr_process_add_arg (comm->process, "-n");
+		}
+		else
+			fr_process_begin_command (comm->process, "uncompress");
 		fr_process_add_arg (comm->process, "-f");
-		fr_process_add_arg (comm->process, e_temp_file);
+		fr_process_add_arg (comm->process, temp_file);
 		fr_process_end_command (comm->process);
-		break;
-
-	case FR_COMPRESS_PROGRAM_LZMA:
+	}
+	else if (is_mime_type (comm->mime_type, "application/x-lzma")) {
 		fr_process_begin_command (comm->process, "lzma");
 		fr_process_add_arg (comm->process, "-f");
 		fr_process_add_arg (comm->process, "-d");
-		fr_process_add_arg (comm->process, e_temp_file);
+		fr_process_add_arg (comm->process, temp_file);
 		fr_process_end_command (comm->process);
-		break;
-
-	case FR_COMPRESS_PROGRAM_LZOP:
+	}
+	else if (is_mime_type (comm->mime_type, "application/x-lzop")) {
 		fr_process_begin_command (comm->process, "lzop");
 		fr_process_set_working_dir (comm->process, temp_dir);
 		fr_process_add_arg (comm->process, "-d");
 		fr_process_add_arg (comm->process, "-fU");
 		fr_process_add_arg (comm->process, "--no-stdin");
-		fr_process_add_arg (comm->process, e_temp_file);
+		fr_process_add_arg (comm->process, temp_file);
+		fr_process_end_command (comm->process);
+	}
+	else if (is_mime_type (comm->mime_type, "application/x-rzip")) {
+		fr_process_begin_command (comm->process, "rzip");
+		fr_process_add_arg (comm->process, "-f");
+		fr_process_add_arg (comm->process, "-d");
+		fr_process_add_arg (comm->process, temp_file);
 		fr_process_end_command (comm->process);
-		break;
 	}
 
 	/* copy uncompress file to the dest dir */
 
 	uncompr_file = remove_extension_from_path (temp_file);
-        e_uncompr_file = fr_command_escape (comm, uncompr_file);
-        
+
 	compr_file = get_uncompressed_name_from_archive (comm, comm->filename);
-	if (compr_file == NULL) 
+	if (compr_file == NULL)
 		compr_file = remove_extension_from_path (file_name_from_path (comm->filename));
 	dest_file = g_strconcat (dest_dir,
 				 "/",
 				 compr_file,
 				 NULL);
-	e_dest_file = fr_command_escape (comm, dest_file);
-	g_free (compr_file);
-	g_free (dest_file);
 
 	fr_process_begin_command (comm->process, "cp");
 	fr_process_add_arg (comm->process, "-f");
-	fr_process_add_arg (comm->process, e_uncompr_file);
-	fr_process_add_arg (comm->process, e_dest_file);
+	fr_process_add_arg (comm->process, uncompr_file);
+	fr_process_add_arg (comm->process, dest_file);
 	fr_process_end_command (comm->process);
 
 	/* remove the temp dir */
@@ -454,20 +414,84 @@ fr_command_cfile_extract (FrCommand  *comm,
 	fr_process_begin_command (comm->process, "rm");
 	fr_process_set_sticky (comm->process, TRUE);
 	fr_process_add_arg (comm->process, "-rf");
-	fr_process_add_arg (comm->process, e_temp_dir);
+	fr_process_add_arg (comm->process, temp_dir);
 	fr_process_end_command (comm->process);
 
-	g_free (e_dest_file);
+	g_free (dest_file);
+	g_free (compr_file);
 	g_free (uncompr_file);
-	g_free (e_uncompr_file);
 	g_free (temp_file);
-	g_free (e_temp_file);
-	g_free (e_temp_dir);
 	g_free (temp_dir);
 }
 
 
-static void 
+const char *cfile_mime_type[] = { "application/x-gzip",
+				  "application/x-bzip",
+				  "application/x-compress",
+				  "application/x-lzma",
+				  "application/x-lzop",
+				  "application/x-rzip",
+				  NULL };
+
+
+const char **
+fr_command_cfile_get_mime_types (FrCommand *comm)
+{
+	return cfile_mime_type;
+}
+
+
+FrCommandCap
+fr_command_cfile_get_capabilities (FrCommand  *comm,
+			           const char *mime_type)
+{
+	FrCommandCap capabilities;
+
+	capabilities = FR_COMMAND_CAN_DO_NOTHING;
+	if (is_mime_type (mime_type, "application/x-gzip")) {
+		if (is_program_in_path ("gzip"))
+			capabilities |= FR_COMMAND_CAN_READ_WRITE;
+	}
+	else if (is_mime_type (mime_type, "application/x-bzip")) {
+		if (is_program_in_path ("bzip2"))
+			capabilities |= FR_COMMAND_CAN_READ_WRITE;
+	}
+	else if (is_mime_type (mime_type, "application/x-compress")) {
+		if (is_program_in_path ("compress"))
+			capabilities |= FR_COMMAND_CAN_WRITE;
+		if (is_program_in_path ("uncompress") || is_program_in_path ("gzip"))
+			capabilities |= FR_COMMAND_CAN_READ;
+	}
+	else if (is_mime_type (mime_type, "application/x-lzma")) {
+		if (is_program_in_path ("lzma"))
+			capabilities |= FR_COMMAND_CAN_READ_WRITE;
+	}
+	else if (is_mime_type (mime_type, "application/x-lzop")) {
+		if (is_program_in_path ("lzop"))
+			capabilities |= FR_COMMAND_CAN_READ_WRITE;
+	}
+	else if (is_mime_type (mime_type, "application/x-rzip")) {
+		if (is_program_in_path ("rzip"))
+			capabilities |= FR_COMMAND_CAN_READ_WRITE;
+	}
+
+	return capabilities;
+}
+
+
+static void
+fr_command_cfile_finalize (GObject *object)
+{
+        g_return_if_fail (object != NULL);
+        g_return_if_fail (FR_IS_COMMAND_CFILE (object));
+
+	/* Chain up */
+        if (G_OBJECT_CLASS (parent_class)->finalize)
+                G_OBJECT_CLASS (parent_class)->finalize (object);
+}
+
+
+static void
 fr_command_cfile_class_init (FrCommandCFileClass *class)
 {
         GObjectClass   *gobject_class = G_OBJECT_CLASS (class);
@@ -478,18 +502,20 @@ fr_command_cfile_class_init (FrCommandCFileClass *class)
 
         gobject_class->finalize = fr_command_cfile_finalize;
 
-        afc->list         = fr_command_cfile_list;
-	afc->add          = fr_command_cfile_add;
-	afc->delete       = fr_command_cfile_delete;
-	afc->extract      = fr_command_cfile_extract;
+        afc->list             = fr_command_cfile_list;
+	afc->add              = fr_command_cfile_add;
+	afc->delete           = fr_command_cfile_delete;
+	afc->extract          = fr_command_cfile_extract;
+	afc->get_mime_types   = fr_command_cfile_get_mime_types;
+	afc->get_capabilities = fr_command_cfile_get_capabilities;
 }
 
- 
-static void 
+
+static void
 fr_command_cfile_init (FrCommand *comm)
 {
-	comm->propAddCanUpdate             = FALSE;
-	comm->propAddCanReplace            = FALSE; 
+	comm->propAddCanUpdate             = TRUE;
+	comm->propAddCanReplace            = TRUE;
 	comm->propExtractCanAvoidOverwrite = FALSE;
 	comm->propExtractCanSkipOlder      = FALSE;
 	comm->propExtractCanJunkPaths      = FALSE;
@@ -498,22 +524,6 @@ fr_command_cfile_init (FrCommand *comm)
 }
 
 
-static void 
-fr_command_cfile_finalize (GObject *object)
-{
-	FrCommandCFile *comm_tar;
-
-        g_return_if_fail (object != NULL);
-        g_return_if_fail (FR_IS_COMMAND_CFILE (object));
-
-	comm_tar = FR_COMMAND_CFILE (object);
-
-	 /* Chain up */
-        if (G_OBJECT_CLASS (parent_class)->finalize)
-                G_OBJECT_CLASS (parent_class)->finalize (object);
-}
-
-
 GType
 fr_command_cfile_get_type ()
 {
@@ -540,62 +550,3 @@ fr_command_cfile_get_type ()
 
         return type;
 }
-
-
-FrCommand *
-fr_command_cfile_new (FrProcess         *process,
-		      const char        *filename,
-		      FRCompressProgram  prog)
-{
-	FrCommand *comm;
-
-	if ((prog == FR_COMPRESS_PROGRAM_GZIP) &&
-	    (!is_program_in_path("gzip"))) {
-		return NULL;
-	}
-
-	if ((prog == FR_COMPRESS_PROGRAM_BZIP) &&
-	    (!is_program_in_path("bzip"))) { 
-		return NULL;
-	}
-
-	if ((prog == FR_COMPRESS_PROGRAM_BZIP2) &&
-	    (!is_program_in_path("bzip2"))) {
-		return NULL;
-	}
-
-	if ((prog == FR_COMPRESS_PROGRAM_COMPRESS) && 
-	    ((!is_program_in_path("compress")) || 
-	     (!is_program_in_path("uncompress")))) {
-		return NULL;
-	}
-
-	if ((prog == FR_COMPRESS_PROGRAM_LZMA) &&
-	    (!is_program_in_path("lzma"))) {
-		return NULL;
-	}
-
-	if ((prog == FR_COMPRESS_PROGRAM_LZOP) &&
-	    (!is_program_in_path("lzop"))) {
-		return NULL;
-	}
-
-	comm = FR_COMMAND (g_object_new (FR_TYPE_COMMAND_CFILE, NULL));
-	fr_command_construct (comm, process, filename);
-	FR_COMMAND_CFILE (comm)->compress_prog = prog;
-
-	if (prog == FR_COMPRESS_PROGRAM_GZIP)
-		comm->file_type = FR_FILE_TYPE_GZIP;
-	else if (prog == FR_COMPRESS_PROGRAM_BZIP)
-		comm->file_type = FR_FILE_TYPE_BZIP;
-	else if (prog == FR_COMPRESS_PROGRAM_BZIP2)
-		comm->file_type = FR_FILE_TYPE_BZIP2;
-	else if (prog == FR_COMPRESS_PROGRAM_COMPRESS)
-		comm->file_type = FR_FILE_TYPE_COMPRESS;
-	else if (prog == FR_COMPRESS_PROGRAM_LZMA)
-		comm->file_type = FR_FILE_TYPE_LZMA;
-	else if (prog == FR_COMPRESS_PROGRAM_LZOP)
-		comm->file_type = FR_FILE_TYPE_LZOP;
-
-	return comm;
-}
