@@ -572,6 +572,9 @@ fr_command_rar_extract (FrCommand  *comm,
 		fr_process_begin_command (comm->process, "unrar");
 
 	fr_process_add_arg (comm->process, "x");
+	
+	/* keep broken extracted files */
+	fr_process_add_arg (comm->process, "-kb");
 
 	if (overwrite)
 		fr_process_add_arg (comm->process, "-o+");
@@ -646,9 +649,10 @@ fr_command_rar_handle_error (FrCommand   *comm,
 	if (error->type != FR_PROC_ERROR_COMMAND_ERROR)
 		return;
 
-	if (error->status == 3)
+	/*if (error->status == 3)
 		error->type = FR_PROC_ERROR_ASK_PASSWORD;
-	else if (error->status <= 1)
+	else */
+	if (error->status <= 1)
 		error->type = FR_PROC_ERROR_NONE;
 
 	for (scan = g_list_last (comm->process->err.raw); scan; scan = scan->prev) {
@@ -659,6 +663,10 @@ fr_command_rar_handle_error (FrCommand   *comm,
 			break;
 		}
 
+		if (strncmp (line, "Unexpected end of archive", 25) == 0) {
+			/* FIXME: handle this type of errors at a higher level when the freeze is over. */
+		}
+
 		if (strncmp (line, "Cannot find volume", 18) == 0) {
 			char *volume_filename;
 
