@@ -127,7 +127,7 @@ process_line (char     *line,
 		else
 			size = g_ascii_strtoull (ssize, NULL, 10);
 
-		if (unstuff_comm->fdata != NULL) 
+		if (unstuff_comm->fdata != NULL)
 			unstuff_comm->fdata->size = size;
 
 		return;
@@ -180,22 +180,29 @@ process_line (char     *line,
 
 
 static void
-fr_command_unstuff_list (FrCommand  *comm,
-			 const char *password)
+list__begin (gpointer data)
+{
+	FrCommandUnstuff *comm = data;
+	
+	comm->fdata = NULL;
+}
+
+
+static void
+fr_command_unstuff_list (FrCommand *comm)
 {
 	char *arg, *path;
 	char *filename;
 	char *path_dots;
 
-	fr_process_set_out_line_func (FR_COMMAND (comm)->process,
-				      process_line,
-				      comm);
+	fr_process_set_out_line_func (comm->process, process_line, comm);
 
 	fr_process_begin_command (comm->process, "unstuff");
+	fr_process_set_begin_func (comm->process, list__begin, comm);
 	fr_process_add_arg (comm->process, "--trace");
 
 	/* Actually unpack everything in a temporary directory */
-	path = get_temp_work_dir ();
+	path = get_temp_work_dir (NULL);
 	path_dots = unstuff_is_shit_with_filenames (path);
 	g_free (path);
 
@@ -214,12 +221,12 @@ fr_command_unstuff_list (FrCommand  *comm,
 
 static void
 fr_command_unstuff_extract (FrCommand  *comm,
+			    const char  *from_file,
 			    GList      *file_list,
 			    const char *dest_dir,
 			    gboolean    overwrite,
 			    gboolean    skip_older,
-			    gboolean    junk_paths,
-			    const char *password)
+			    gboolean    junk_paths)
 {
 #if 0
 	GList *scan;
@@ -231,7 +238,7 @@ fr_command_unstuff_extract (FrCommand  *comm,
 	if (dest_dir != NULL) {
 		char *dest_dir_dots;
 		char *arg;
-		
+
 		dest_dir_dots = unstuff_is_shit_with_filenames (dest_dir);
 		arg = g_strdup_printf ("-d=%s", dest_dir_dots);
 		fr_process_add_arg (comm->process, arg);
@@ -259,7 +266,7 @@ fr_command_unstuff_extract (FrCommand  *comm,
 
 static void
 fr_command_unstuff_handle_error (FrCommand   *comm,
-			     FrProcError *error)
+				 FrProcError *error)
 {
 	if ((error->type == FR_PROC_ERROR_COMMAND_ERROR)
 	    && (error->status <= 1))
@@ -267,15 +274,27 @@ fr_command_unstuff_handle_error (FrCommand   *comm,
 }
 
 
-static void
-fr_command_unstuff_set_mime_type (FrCommand  *comm,
-			          const char *mime_type)
+const char *unstuff_mime_type[] = { "application/x-stuffit", NULL };
+
+
+const char **
+fr_command_unstuff_get_mime_types (FrCommand *comm)
 {
-	FR_COMMAND_CLASS (parent_class)->set_mime_type (comm, mime_type);
-	
-	comm->capabilities |= FR_COMMAND_CAP_ARCHIVE_MANY_FILES;
-	if (is_program_in_path ("unstuff")) 
-		comm->capabilities |= FR_COMMAND_CAP_READ;
+	return unstuff_mime_type;
+}
+
+
+FrCommandCap
+fr_command_unstuff_get_capabilities (FrCommand  *comm,
+			             const char *mime_type)
+{
+	FrCommandCap capabilities;
+
+	capabilities = FR_COMMAND_CAN_ARCHIVE_MANY_FILES;
+	if (is_program_in_path ("unstuff"))
+		capabilities |= FR_COMMAND_CAN_READ;
+
+	return capabilities;
 }
 
 
@@ -290,12 +309,13 @@ fr_command_unstuff_class_init (FrCommandUnstuffClass *class)
 
 	gobject_class->finalize = fr_command_unstuff_finalize;
 
-	afc->list           = fr_command_unstuff_list;
-	afc->add            = NULL;
-	afc->delete         = NULL;
-	afc->extract        = fr_command_unstuff_extract;
-	afc->handle_error   = fr_command_unstuff_handle_error;
-	afc->set_mime_type  = fr_command_unstuff_set_mime_type;
+	afc->list             = fr_command_unstuff_list;
+	afc->add              = NULL;
+	afc->delete           = NULL;
+	afc->extract          = fr_command_unstuff_extract;
+	afc->handle_error     = fr_command_unstuff_handle_error;
+	afc->get_mime_types   = fr_command_unstuff_get_mime_types;
+	afc->get_capabilities = fr_command_unstuff_get_capabilities;
 }
 
 
