@@ -6,10 +6,18 @@
 
 G_BEGIN_DECLS
 
-/* VOID:INT (fr-marshal.list:1) */
+/* VOID:INT (/home/paolo/workspace/file-roller/src/fr-marshal.list:1) */
 #define fr_marshal_VOID__INT	g_cclosure_marshal_VOID__INT
 
-/* VOID:INT,POINTER (fr-marshal.list:2) */
+/* VOID:INT,INT (/home/paolo/workspace/file-roller/src/fr-marshal.list:2) */
+extern void fr_marshal_VOID__INT_INT (GClosure     *closure,
+                                      GValue       *return_value,
+                                      guint         n_param_values,
+                                      const GValue *param_values,
+                                      gpointer      invocation_hint,
+                                      gpointer      marshal_data);
+
+/* VOID:INT,POINTER (/home/paolo/workspace/file-roller/src/fr-marshal.list:3) */
 extern void fr_marshal_VOID__INT_POINTER (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -17,19 +25,19 @@ extern void fr_marshal_VOID__INT_POINTER (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:POINTER (fr-marshal.list:3) */
+/* VOID:POINTER (/home/paolo/workspace/file-roller/src/fr-marshal.list:4) */
 #define fr_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
 
-/* VOID:VOID (fr-marshal.list:4) */
+/* VOID:VOID (/home/paolo/workspace/file-roller/src/fr-marshal.list:5) */
 #define fr_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
 
-/* VOID:DOUBLE (fr-marshal.list:5) */
+/* VOID:DOUBLE (/home/paolo/workspace/file-roller/src/fr-marshal.list:6) */
 #define fr_marshal_VOID__DOUBLE	g_cclosure_marshal_VOID__DOUBLE
 
-/* VOID:STRING (fr-marshal.list:6) */
+/* VOID:STRING (/home/paolo/workspace/file-roller/src/fr-marshal.list:7) */
 #define fr_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING
 
-/* VOID:BOOL (fr-marshal.list:7) */
+/* VOID:BOOL (/home/paolo/workspace/file-roller/src/fr-marshal.list:8) */
 #define fr_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN
 #define fr_marshal_VOID__BOOL	fr_marshal_VOID__BOOLEAN
 
